#![feature(exit_status_error)]
use std::{thread, time};

use crate::action::build;
use crate::action::cleanup;
use crate::action::update_ports_tree;
use crate::action::ACTION_BUILD;
use crate::action::ACTION_CLEANUP;
use crate::action::ACTION_UPDATE_PORTS_TREE;

mod action;
mod db;

fn main() -> Result<(), Box<dyn std::error::Error>> {
    let db_path = std::env::args()
        .nth(1)
        .ok_or("Pass path to sqlite DB in first parameter.")?;
    let mut db_conn: db::DbHandle = db::DbHandle::new(db_path)?;

    loop {
        for pending_global_action in db_conn.get_pending_global_actions()? {
            match pending_global_action.name.as_str() {
                ACTION_UPDATE_PORTS_TREE => {
                    update_ports_tree(&mut db_conn)?;
                }
                ACTION_CLEANUP => {
                    cleanup(&mut db_conn)?;
                }
                _ => {
                    panic!("Unknown global action: {}", pending_global_action.name);
                }
            };
        }

        for pending_local_action in db_conn.get_pending_local_actions()? {
            match pending_local_action.name.as_str() {
                ACTION_BUILD => {
                    build(&mut db_conn, &pending_local_action)?;
                }
                _ => {
                    panic!("Unknown local action: {}", pending_local_action.name);
                }
            }
        }

        let time_until_next_action = db_conn.get_time_until_next_action()?;
        let sleep_duration = std::cmp::min(
            time::Duration::from_secs(60),
            std::cmp::max(time_until_next_action, time::Duration::from_secs(300)),
        );
        println!("Sleeping for {} seconds.", sleep_duration.as_secs());
        thread::sleep(sleep_duration);
    }
}
